# This is a fix for InnoDB in MySQL >= 4.1.x
# It "suspends judgement" for fkey relationships until are tables are set.

SET FOREIGN_KEY_CHECKS = 0;
# -----------------------------------------------------------------------
# user 
# -----------------------------------------------------------------------
DROP TABLE IF EXISTS `user`;

CREATE TABLE `user`(
    `id` INTEGER NOT NULL AUTO_INCREMENT, 
    `username` VARCHAR(128) NOT NULL , 
    `password` VARCHAR(128) NOT NULL , 
    `last_login` DATETIME , 
    `reg_date` DATETIME NOT NULL , 
    `level` INTEGER NOT NULL , 
    `enabled` INTEGER , 
    `posts` INTEGER NOT NULL , 
    `comments` INTEGER , 
    `timezone` INTEGER NOT NULL , 
    `language` VARCHAR(255) , 
    `new_msg` INTEGER NOT NULL , 
    `unread_msg` INTEGER NOT NULL , 
    `email` VARCHAR(255) , 
    `signiture` TEXT , 
    `custom_info` TEXT ,  
    PRIMARY KEY(`id`))
Type=MyISAM;
# -----------------------------------------------------------------------
# group 
# -----------------------------------------------------------------------
DROP TABLE IF EXISTS `group`;

CREATE TABLE `group`(
    `id` INTEGER NOT NULL AUTO_INCREMENT, 
    `type` INTEGER NOT NULL , 
    `name` VARCHAR(255) NOT NULL , 
    `description` TEXT , 
    `custom_info` TEXT ,  
    PRIMARY KEY(`id`))
Type=MyISAM;
# -----------------------------------------------------------------------
# user_group 
# -----------------------------------------------------------------------
DROP TABLE IF EXISTS `user_group`;

CREATE TABLE `user_group`(
    `group_id` INTEGER NOT NULL , 
    `user_id` INTEGER NOT NULL ,  
    PRIMARY KEY(`group_id`,`user_id`),  
    CONSTRAINT `user_group_FK_1` 
      FOREIGN KEY (`group_id`)
      REFERENCES `group` (`id`)
, 
    INDEX `user_group_FI_2` (`user_id`), 
    CONSTRAINT `user_group_FK_2` 
      FOREIGN KEY (`user_id`)
      REFERENCES `user` (`id`)
)
Type=MyISAM;
# -----------------------------------------------------------------------
# message 
# -----------------------------------------------------------------------
DROP TABLE IF EXISTS `message`;

CREATE TABLE `message`(
    `id` INTEGER NOT NULL AUTO_INCREMENT, 
    `type` INTEGER NOT NULL , 
    `subject` VARCHAR(255) NOT NULL , 
    `from` INTEGER NOT NULL , 
    `to` INTEGER NOT NULL , 
    `date` DATETIME NOT NULL , 
    `ip` VARCHAR(64) NOT NULL ,  
    PRIMARY KEY(`id`),  
    INDEX `message_FI_1` (`from`), 
    CONSTRAINT `message_FK_1` 
      FOREIGN KEY (`from`)
      REFERENCES `user` (`id`)
, 
    INDEX `message_FI_2` (`to`), 
    CONSTRAINT `message_FK_2` 
      FOREIGN KEY (`to`)
      REFERENCES `user` (`id`)
)
Type=MyISAM;
# -----------------------------------------------------------------------
# page 
# -----------------------------------------------------------------------
DROP TABLE IF EXISTS `page`;

CREATE TABLE `page`(
    `id` INTEGER NOT NULL AUTO_INCREMENT, 
    `title` VARCHAR(255) NOT NULL , 
    `text` TEXT , 
    `auth_read` INTEGER NOT NULL , 
    `auth_edit` INTEGER NOT NULL , 
    `auth_delete` INTEGER NOT NULL , 
    `auth_attatchment` INTEGER NOT NULL , 
    `custom_info` TEXT ,  
    PRIMARY KEY(`id`))
Type=MyISAM;
# -----------------------------------------------------------------------
# category 
# -----------------------------------------------------------------------
DROP TABLE IF EXISTS `category`;

CREATE TABLE `category`(
    `id` INTEGER NOT NULL AUTO_INCREMENT, 
    `name` VARCHAR(255) NOT NULL , 
    `description` TEXT , 
    `order` INTEGER NOT NULL , 
    `custom_info` TEXT ,  
    PRIMARY KEY(`id`,`order`))
Type=MyISAM;
# -----------------------------------------------------------------------
# forum 
# -----------------------------------------------------------------------
DROP TABLE IF EXISTS `forum`;

CREATE TABLE `forum`(
    `id` INTEGER NOT NULL AUTO_INCREMENT, 
    `category_id` INTEGER NOT NULL , 
    `name` VARCHAR(64) NOT NULL , 
    `description` TEXT , 
    `order` INTEGER NOT NULL , 
    `status` INTEGER NOT NULL , 
    `posts` INTEGER NOT NULL , 
    `topics` INTEGER NOT NULL , 
    `last_poster` INTEGER NOT NULL , 
    `auth_view` INTEGER NOT NULL , 
    `auth_read` INTEGER NOT NULL , 
    `auth_post` INTEGER NOT NULL , 
    `auth_reply` INTEGER NOT NULL , 
    `auth_edit` INTEGER NOT NULL , 
    `auth_delete` INTEGER NOT NULL , 
    `auth_sticky` INTEGER NOT NULL , 
    `auth_announce` INTEGER NOT NULL , 
    `auth_vote` INTEGER NOT NULL , 
    `auth_pollcreate` INTEGER NOT NULL , 
    `auth_attatchment` INTEGER NOT NULL , 
    `custom_info` TEXT ,  
    PRIMARY KEY(`id`,`category_id`),  
    INDEX `forum_FI_1` (`category_id`), 
    CONSTRAINT `forum_FK_1` 
      FOREIGN KEY (`category_id`)
      REFERENCES `category` (`id`)
, 
    INDEX `forum_FI_2` (`last_poster`), 
    CONSTRAINT `forum_FK_2` 
      FOREIGN KEY (`last_poster`)
      REFERENCES `user` (`id`)
)
Type=MyISAM;
# -----------------------------------------------------------------------
# topic 
# -----------------------------------------------------------------------
DROP TABLE IF EXISTS `topic`;

CREATE TABLE `topic`(
    `id` INTEGER NOT NULL AUTO_INCREMENT, 
    `forum_id` INTEGER NOT NULL , 
    `title` VARCHAR(255) NOT NULL , 
    `poster` INTEGER NOT NULL , 
    `poster_username` VARCHAR(128) NOT NULL , 
    `created_at` DATETIME NOT NULL , 
    `updated_at` DATETIME NOT NULL , 
    `views` INTEGER NOT NULL , 
    `replies` INTEGER NOT NULL , 
    `type` INTEGER NOT NULL , 
    `custom_info` TEXT ,  
    PRIMARY KEY(`id`,`forum_id`),  
    INDEX `topic_FI_1` (`forum_id`), 
    CONSTRAINT `topic_FK_1` 
      FOREIGN KEY (`forum_id`)
      REFERENCES `forum` (`id`)
, 
    INDEX `topic_FI_2` (`poster`), 
    CONSTRAINT `topic_FK_2` 
      FOREIGN KEY (`poster`)
      REFERENCES `user` (`id`)
)
Type=MyISAM;
# -----------------------------------------------------------------------
# post 
# -----------------------------------------------------------------------
DROP TABLE IF EXISTS `post`;

CREATE TABLE `post`(
    `id` INTEGER NOT NULL AUTO_INCREMENT, 
    `topic_id` INTEGER NOT NULL , 
    `forum_id` INTEGER NOT NULL , 
    `poster` INTEGER NOT NULL , 
    `poster_ip` VARCHAR(64) NOT NULL , 
    `poster_username` VARCHAR(128) NOT NULL , 
    `created_at` DATETIME NOT NULL , 
    `updated_at` DATETIME NOT NULL , 
    `reply_of` INTEGER , 
    `text` TEXT , 
    `custom_info` TEXT ,  
    PRIMARY KEY(`id`,`topic_id`,`forum_id`),  
    INDEX `post_FI_1` (`topic_id`), 
    CONSTRAINT `post_FK_1` 
      FOREIGN KEY (`topic_id`)
      REFERENCES `topic` (`id`)
, 
    INDEX `post_FI_2` (`forum_id`), 
    CONSTRAINT `post_FK_2` 
      FOREIGN KEY (`forum_id`)
      REFERENCES `forum` (`id`)
, 
    INDEX `post_FI_3` (`poster`), 
    CONSTRAINT `post_FK_3` 
      FOREIGN KEY (`poster`)
      REFERENCES `user` (`id`)
, 
    INDEX `post_FI_4` (`reply_of`), 
    CONSTRAINT `post_FK_4` 
      FOREIGN KEY (`reply_of`)
      REFERENCES `post` (`id`)
)
Type=MyISAM;
  
  
  
  
  
  
  
  
  
# This restores the fkey checks, after having unset them
# in database-start.tpl

SET FOREIGN_KEY_CHECKS = 1;

