<?php

require_once 'propel/om/BaseObject.php';

require_once 'propel/om/Persistent.php';


include_once 'propel/util/Criteria.php';

include_once 'model/MessagePeer.php';

/**
 * Base class that represents a row from the 'message' table.
 *
 * 
 *
 * @package model.om
 */	
abstract class BaseMessage extends BaseObject  implements Persistent {


	/**
	 * phpname type
	 * e.g. 'AuthorId'
	 */
	const TYPE_PHPNAME = 'phpName';

	/**
	 * column (peer) name type
	 * e.g. 'book.AUTHOR_ID'
	 */
	const TYPE_COLNAME = 'colName';

	/**
	 * column fieldname type
	 * e.g. 'author_id'
	 */
	const TYPE_FIELDNAME = 'fieldName';

	/**
	 * num type
	 * simply the numerical array index, e.g. 4
	 */
	const TYPE_NUM = 'num';

	/** 
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var MessagePeer
	 */
	protected static $peer;


	/**
	 * The value for the id field.
	 * @var int
	 */
	protected $id;


	/**
	 * The value for the type field.
	 * @var int
	 */
	protected $type;


	/**
	 * The value for the subject field.
	 * @var string
	 */
	protected $subject;


	/**
	 * The value for the from field.
	 * @var int
	 */
	protected $from;


	/**
	 * The value for the to field.
	 * @var int
	 */
	protected $to;


	/**
	 * The value for the date field.
	 * @var int
	 */
	protected $date;


	/**
	 * The value for the ip field.
	 * @var string
	 */
	protected $ip;

	/**
	 * holds an array of fieldnames
	 *
	 * first dimension keys are the type constants
	 * e.g. self::$fieldNames[self::TYPE_PHPNAME][0] = 'Id'
	 */
	private static $fieldNames = array (
		Message::TYPE_PHPNAME => array ('Id', 'Type', 'Subject', 'From', 'To', 'Date', 'Ip', ),
		Message::TYPE_COLNAME => array (MessagePeer::ID, MessagePeer::TYPE, MessagePeer::SUBJECT, MessagePeer::FROM, MessagePeer::TO, MessagePeer::DATE, MessagePeer::IP, ),
		
		Message::TYPE_FIELDNAME => array ('id', 'type', 'subject', 'from', 'to', 'date', 'ip', ),
		
		Message::TYPE_NUM => array (0, 1, 2, 3, 4, 5, 6, )
	);

	/**
	 * holds an array of keys for quick access to the fieldnames array
	 *
	 * first dimension keys are the type constants
	 * e.g. self::$fieldNames[self::TYPE_PHPNAME]['Id'] = 0
	 */
	private static $fieldKeys = array (
		Message::TYPE_PHPNAME => array ('Id' => 0, 'Type' => 1, 'Subject' => 2, 'From' => 3, 'To' => 4, 'Date' => 5, 'Ip' => 6, ),
		Message::TYPE_COLNAME => array (MessagePeer::ID => 0, MessagePeer::TYPE => 1, MessagePeer::SUBJECT => 2, MessagePeer::FROM => 3, MessagePeer::TO => 4, MessagePeer::DATE => 5, MessagePeer::IP => 6, ),
		
		Message::TYPE_FIELDNAME => array ('id' => 0, 'type' => 1, 'subject' => 2, 'from' => 3, 'to' => 4, 'date' => 5, 'ip' => 6, ),
		
		Message::TYPE_NUM => array (0, 1, 2, 3, 4, 5, 6, )
	);

	/**
	 * @var User
	 */
	protected $aUserRelatedByFrom;

	/**
	 * @var User
	 */
	protected $aUserRelatedByTo;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var boolean
	 */
	private $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var boolean
	 */
	private $alreadyInValidation = false;

	/**
	 * Get the [id] column value.
	 * 
	 * @return int
	 */
	public function getId()
	{

		return $this->id;
	}

	/**
	 * Get the [type] column value.
	 * 
	 * @return int
	 */
	public function getType()
	{

		return $this->type;
	}

	/**
	 * Get the [subject] column value.
	 * 
	 * @return string
	 */
	public function getSubject()
	{

		return $this->subject;
	}

	/**
	 * Get the [from] column value.
	 * 
	 * @return int
	 */
	public function getFrom()
	{

		return $this->from;
	}

	/**
	 * Get the [to] column value.
	 * 
	 * @return int
	 */
	public function getTo()
	{

		return $this->to;
	}

	/**
	 * Get the [optionally formatted] [date] column value.
	 * 
	 * @param string $format The date/time format string (either date()-style or strftime()-style).
	 *							If format is NULL, then the integer unix timestamp will be returned.
	 * @return mixed Formatted date/time value as string or integer unix timestamp (if format is NULL).
	 * @throws PropelException - if unable to convert the date/time to timestamp.
	 */
	public function getDate($format = 'Y-m-d H:i:s')
	{

		if ($this->date === null || $this->date === '') {
			return null;
		} elseif (!is_int($this->date)) {
			// a non-timestamp value was set externally, so we convert it
			$ts = strtotime($this->date);
			if ($ts === -1) {
				throw new PropelException("Unable to parse value of [date] as date/time value: " . var_export($this->date, true));
			}
		} else {
			$ts = $this->date;
		}
		if ($format === null) {
			return $ts;
		} elseif (strpos($format, '%') !== false) {
			return strftime($format, $ts);
		} else {
			return date($format, $ts);
		}
	}

	/**
	 * Get the [ip] column value.
	 * 
	 * @return string
	 */
	public function getIp()
	{

		return $this->ip;
	}

	/**
	 * Set the value of [id] column.	  
	 * 
	 * @param int $v new value
	 * @return void
	 */
	public function setId($v)
	{

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = MessagePeer::ID;
		}

	} // setId()

	/**
	 * Set the value of [type] column.	  
	 * 
	 * @param int $v new value
	 * @return void
	 */
	public function setType($v)
	{

		if ($this->type !== $v) {
			$this->type = $v;
			$this->modifiedColumns[] = MessagePeer::TYPE;
		}

	} // setType()

	/**
	 * Set the value of [subject] column.	  
	 * 
	 * @param string $v new value
	 * @return void
	 */
	public function setSubject($v)
	{

		if ($this->subject !== $v) {
			$this->subject = $v;
			$this->modifiedColumns[] = MessagePeer::SUBJECT;
		}

	} // setSubject()

	/**
	 * Set the value of [from] column.	  
	 * 
	 * @param int $v new value
	 * @return void
	 */
	public function setFrom($v)
	{

		if ($this->from !== $v) {
			$this->from = $v;
			$this->modifiedColumns[] = MessagePeer::FROM;
		}

		if ($this->aUserRelatedByFrom !== null && $this->aUserRelatedByFrom->getId() !== $v) {
			$this->aUserRelatedByFrom = null;
		}		

	} // setFrom()

	/**
	 * Set the value of [to] column.	  
	 * 
	 * @param int $v new value
	 * @return void
	 */
	public function setTo($v)
	{

		if ($this->to !== $v) {
			$this->to = $v;
			$this->modifiedColumns[] = MessagePeer::TO;
		}

		if ($this->aUserRelatedByTo !== null && $this->aUserRelatedByTo->getId() !== $v) {
			$this->aUserRelatedByTo = null;
		}		

	} // setTo()

	/**
	 * Set the value of [date] column.	  
	 * 
	 * @param int $v new value
	 * @return void
	 */
	public function setDate($v)
	{

		if ($v !== null && !is_int($v)) {
			$ts = strtotime($v);
			if ($ts === -1) {
				throw new PropelException("Unable to parse date/time value for [date] from input: " . var_export($v, true));
			}
		} else {
			$ts = $v;
		}
		if ($this->date !== $ts) {
			$this->date = $ts;
			$this->modifiedColumns[] = MessagePeer::DATE;
		}

	} // setDate()

	/**
	 * Set the value of [ip] column.	  
	 * 
	 * @param string $v new value
	 * @return void
	 */
	public function setIp($v)
	{

		if ($this->ip !== $v) {
			$this->ip = $v;
			$this->modifiedColumns[] = MessagePeer::IP;
		}

	} // setIp()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (1-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param ResultSet $rs The ResultSet class with cursor advanced to desired record pos.
	 * @param int $startcol 1-based offset column which indicates which restultset column to start with.
	 * @return int next starting column
	 * @throws PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate(ResultSet $rs, $startcol = 1)
	{
		try {

			$this->id = $rs->getInt($startcol + 0);

			$this->type = $rs->getInt($startcol + 1);

			$this->subject = $rs->getString($startcol + 2);

			$this->from = $rs->getInt($startcol + 3);

			$this->to = $rs->getInt($startcol + 4);

			$this->date = $rs->getTimestamp($startcol + 5, null);

			$this->ip = $rs->getString($startcol + 6);

			$this->resetModified();

			$this->setNew(false);
						
			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 7; // 7 = MessagePeer::NUM_COLUMNS - MessagePeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating Message object", $e);
		}
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param Connection $con
	 * @return void
	 * @throws PropelException
	 * @see BaseObject::setDeleted()
	 * @see BaseObject::isDeleted()
	 */
	public function delete($con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(MessagePeer::DATABASE_NAME);
		}
		
		try {
			$con->begin();
			MessagePeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollback();
			throw $e;
		}
	}

	/**
	 * Stores the object in the database.  If the object is new,
	 * it inserts it; otherwise an update is performed.  This method
	 * wraps the doSave() worker method in a transaction.
	 *
	 * @param Connection $con
	 * @return int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws PropelException
	 * @see doSave()
	 */
	public function save($con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(MessagePeer::DATABASE_NAME);
		}
		
		try {
			$con->begin();
			$affectedRows = $this->doSave($con);
			$con->commit();
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollback();
			throw $e;
		}
	}

	/**
	 * Stores the object in the database.
	 * 
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param Connection $con
	 * @return int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws PropelException
	 * @see save()
	 */
	protected function doSave($con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows	
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;


			// We call the save method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aUserRelatedByFrom !== null) {
				if ($this->aUserRelatedByFrom->isModified()) {
					$affectedRows += $this->aUserRelatedByFrom->save($con);
				}
				$this->setUserRelatedByFrom($this->aUserRelatedByFrom);
			}

			if ($this->aUserRelatedByTo !== null) {
				if ($this->aUserRelatedByTo->isModified()) {
					$affectedRows += $this->aUserRelatedByTo->save($con);
				}
				$this->setUserRelatedByTo($this->aUserRelatedByTo);
			}
	

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = MessagePeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which 
										 // should always be true here (even though technically 
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += MessagePeer::doUpdate($this, $con);
				}
				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			$this->alreadyInSave = false;
		}
		return $affectedRows;
	} // doSave()

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param mixed $columns Column name or an array of column names.
	 *
	 * @return mixed <code>true</code> if all columns pass validation
	 *			  or an array of <code>ValidationFailed</code> objects for columns that fail.
	 * @see doValidate()
	 */
	public function validate($columns = null)
	{
	  if ($columns) {
		return MessagePeer::doValidate($this, $columns);
	  }
		return $this->doValidate();
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @return mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate()
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			// We call the validate method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aUserRelatedByFrom !== null) {
				if (($retval = $this->aUserRelatedByFrom->validate()) !== true) {
					$failureMap = array_merge($failureMap, $retval);
				}
			}

			if ($this->aUserRelatedByTo !== null) {
				if (($retval = $this->aUserRelatedByTo->validate()) !== true) {
					$failureMap = array_merge($failureMap, $retval);
				}
			}


			if (($retval = MessagePeer::doValidate($this)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}



			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Translates a fieldname to another type
	 *
	 * @param string $name field name
	 * @param string $fromType One of the class type constants TYPE_PHPNAME,
	 *                         TYPE_COLNAME, TYPE_FIELDNAME, TYPE_NUM
	 * @param string $toType   One of the class type constants
	 * @return string translated name of the field.
	 */
	static public function translateFieldName($name, $fromType, $toType)
	{
		$toNames = self::getFieldNames($toType);
		$key = self::$fieldKeys[$fromType][$name];
		if ($key === false) {
			throw new PropelException("'$name' could not be found in the field names of type '$fromType'. These are: " . print_r($fromNames, true));
		}
		return $toNames[$key];
	}

	/**
	 * Returns an array of of field names.
	 *
	 * @param  string $type The type of fieldnames to return:
	 *                      One of the class type constants TYPE_PHPNAME,
	 *                      TYPE_COLNAME, TYPE_FIELDNAME, TYPE_NUM
	 * @return array A list of field names
	 */

	static public function getFieldNames($type = self::TYPE_FIELDNAME)
	{
		if (!isset(self::$fieldNames[$type])) {
			throw new PropelException('Method getFieldNames() expects the parameter $type to be one of the class constants TYPE_PHPNAME, TYPE_COLNAME, TYPE_FIELDNAME, TYPE_NUM. ' . $type . ' was given.');
		}
		return self::$fieldNames[$type];
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param string $name name
	 * @param string $type The type of fieldname the $name is of:
	 *                     one of the class type constants TYPE_PHPNAME,
	 *                     TYPE_COLNAME, TYPE_FIELDNAME, TYPE_NUM
	 * @return mixed Value of field.
	 */
	public function getByName($name, $type = self::TYPE_COLNAME)
	{
		$names = self::getFieldNames($type);
		$pos = self::translateFieldName($name, $type, self::TYPE_NUM);
		return $this->getByPosition($pos);
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param int $pos position in xml schema
	 * @return mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {

			case 0:
				return $this->getId();
				break;

			case 1:
				return $this->getType();
				break;

			case 2:
				return $this->getSubject();
				break;

			case 3:
				return $this->getFrom();
				break;

			case 4:
				return $this->getTo();
				break;

			case 5:
				return $this->getDate();
				break;

			case 6:
				return $this->getIp();
				break;

			default:
				return null;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param string $keyType One of the class type constants TYPE_PHPNAME,
	 *                        TYPE_COLNAME, TYPE_FIELDNAME, TYPE_NUM
	 * @return an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = self::TYPE_PHPNAME)
	{
		$keys = self::getFieldNames($keyType);
		$result = array(

			$keys[0] => $this->getId(),

			$keys[1] => $this->getType(),

			$keys[2] => $this->getSubject(),

			$keys[3] => $this->getFrom(),

			$keys[4] => $this->getTo(),

			$keys[5] => $this->getDate(),

			$keys[6] => $this->getIp(),

		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param string $name peer name
	 * @param mixed $value field value
	 * @param string $type The type of fieldname the $name is of:
	 *                     one of the class type constants TYPE_PHPNAME,
	 *                     TYPE_COLNAME, TYPE_FIELDNAME, TYPE_NUM
	 * @return void
	 */
	public function setByName($name, $value, $type = self::TYPE_COLNAME)
	{
		$names = $this->getFieldnames($type);
		$pos = array_search($name, $names);
		return $this->setByPosition($pos, $name);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param int $pos position in xml schema
	 * @param mixed $value field value
	 * @return void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {

			case 0:
				$this->setId($value);
				break;
		
			case 1:
				$this->setType($value);
				break;
		
			case 2:
				$this->setSubject($value);
				break;
		
			case 3:
				$this->setFrom($value);
				break;
		
			case 4:
				$this->setTo($value);
				break;
		
			case 5:
				$this->setDate($value);
				break;
		
			case 6:
				$this->setIp($value);
				break;
		
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants TYPE_PHPNAME, TYPE_COLNAME, TYPE_FIELDNAME,
	 * TYPE_NUM. The default key type is the (peer) column name (e.g.
	 * 'book.AUTHOR_ID')
	 *
	 * @param array  $arr     An array to populate the object from.
	 * @param string $keyType The type of keys the array uses.
	 * @return void
	 */
	public function fromArray($arr, $keyType = self::TYPE_COLNAME)
	{
		$keys = self::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);

		if (array_key_exists($keys[1], $arr)) $this->setType($arr[$keys[1]]);

		if (array_key_exists($keys[2], $arr)) $this->setSubject($arr[$keys[2]]);

		if (array_key_exists($keys[3], $arr)) $this->setFrom($arr[$keys[3]]);

		if (array_key_exists($keys[4], $arr)) $this->setTo($arr[$keys[4]]);

		if (array_key_exists($keys[5], $arr)) $this->setDate($arr[$keys[5]]);

		if (array_key_exists($keys[6], $arr)) $this->setIp($arr[$keys[6]]);

	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(MessagePeer::DATABASE_NAME);

		if ($this->isColumnModified(MessagePeer::ID)) $criteria->add(MessagePeer::ID, $this->id);

		if ($this->isColumnModified(MessagePeer::TYPE)) $criteria->add(MessagePeer::TYPE, $this->type);

		if ($this->isColumnModified(MessagePeer::SUBJECT)) $criteria->add(MessagePeer::SUBJECT, $this->subject);

		if ($this->isColumnModified(MessagePeer::FROM)) $criteria->add(MessagePeer::FROM, $this->from);

		if ($this->isColumnModified(MessagePeer::TO)) $criteria->add(MessagePeer::TO, $this->to);

		if ($this->isColumnModified(MessagePeer::DATE)) $criteria->add(MessagePeer::DATE, $this->date);

		if ($this->isColumnModified(MessagePeer::IP)) $criteria->add(MessagePeer::IP, $this->ip);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(MessagePeer::DATABASE_NAME);

		$criteria->add(MessagePeer::ID, $this->id);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return int 
	 */
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	/**
	 * Generic method to set the primary key (id column).
	 *
	 * @param int $key Primary key.
	 * @return void
	 */
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 * 
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param object $copyObj An object of Message (or compatible) type.
	 * @param boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setType($this->type);

		$copyObj->setSubject($this->subject);

		$copyObj->setFrom($this->from);

		$copyObj->setTo($this->to);

		$copyObj->setDate($this->date);

		$copyObj->setIp($this->ip);


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a pkey column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 * 
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return Message Clone of current object.
	 * @throws PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 * 
	 * @return MessagePeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new MessagePeer();
		}
		return self::$peer;
	}

	/**
	 * Declares an association between this object and a User object.
	 *
	 * @param User $v
	 * @return void
	 * @throws PropelException
	 */
	public function setUserRelatedByFrom($v)
	{


		if ($v === null) {
			$this->setFrom(NULL);
		} else {
			$this->setFrom($v->getId());
		}


		$this->aUserRelatedByFrom = $v;
	}


	/**
	 * Get the associated User object
	 *
	 * @param Connection Optional Connection object.
	 * @return User The associated User object.
	 * @throws PropelException
	 */
	public function getUserRelatedByFrom($con = null)
	{
		// include the related Peer class
		include_once 'model/om/BaseUserPeer.php';

		if ($this->aUserRelatedByFrom === null && ($this->from !== null)) {

			$this->aUserRelatedByFrom = UserPeer::retrieveByPK($this->from, $con);
					
			/* The following can be used instead of the line above to
			   guarantee the related object contains a reference
			   to this object, but this level of coupling
			   may be undesirable in many circumstances.
			   As it can lead to a db query with many results that may
			   never be used.
			   $obj = UserPeer::retrieveByPK($this->from, $con);
			   $obj->addUsersRelatedByFrom($this);
			 */
		}
		return $this->aUserRelatedByFrom;
	}

	/**
	 * Declares an association between this object and a User object.
	 *
	 * @param User $v
	 * @return void
	 * @throws PropelException
	 */
	public function setUserRelatedByTo($v)
	{


		if ($v === null) {
			$this->setTo(NULL);
		} else {
			$this->setTo($v->getId());
		}


		$this->aUserRelatedByTo = $v;
	}


	/**
	 * Get the associated User object
	 *
	 * @param Connection Optional Connection object.
	 * @return User The associated User object.
	 * @throws PropelException
	 */
	public function getUserRelatedByTo($con = null)
	{
		// include the related Peer class
		include_once 'model/om/BaseUserPeer.php';

		if ($this->aUserRelatedByTo === null && ($this->to !== null)) {

			$this->aUserRelatedByTo = UserPeer::retrieveByPK($this->to, $con);
					
			/* The following can be used instead of the line above to
			   guarantee the related object contains a reference
			   to this object, but this level of coupling
			   may be undesirable in many circumstances.
			   As it can lead to a db query with many results that may
			   never be used.
			   $obj = UserPeer::retrieveByPK($this->to, $con);
			   $obj->addUsersRelatedByTo($this);
			 */
		}
		return $this->aUserRelatedByTo;
	}

} // BaseMessage
